///////////////////////////////////////////////////////////////////////////////
// Name:        gui.h
// Purpose:     Header for gui code
// Author:      Chad Rempp
// Modified by: Chad Rempp
// Created:     05-20-03
// Copyright:   (c) 2003 Chad Rempp
// Licence:     GNU Public License (hey it's what all my friends are doing)
///////////////////////////////////////////////////////////////////////////////

#ifndef _NGUI_H
#define _NGUI_H

#include <wx/wx.h>
#include "nviz3d/nviz3d.h"

///////////////////////////////////////////////////////////////////////////////
// NguiApp class Declaration
///////////////////////////////////////////////////////////////////////////////

class NguiApp: public wxApp
{
public:
    virtual bool OnInit();
};


///////////////////////////////////////////////////////////////////////////////
// NguiFrame class Declaration
///////////////////////////////////////////////////////////////////////////////
class NguiFrame: public wxFrame
{
public:
    NguiFrame(const wxString &title, const wxPoint &pos, const wxSize &size,
              long style);
    void OnAbout(wxCommandEvent &event);
    void OnLoadNetwork(wxCommandEvent &event);
    void OnNewNetwork(wxCommandEvent &event);
    void OnOpenLog(wxCommandEvent &event);
    void OnQuit(wxCommandEvent &event);
    void OnSaveNetwork(wxCommandEvent &event);
    void Log(wxString str){/*txt_log << str*/};

private:
    wxDialog *dlg_log;
    wxTextCtrl *txt_log;
    DECLARE_EVENT_TABLE()
};

///////////////////////////////////////////////////////////////////////////////
// NetDialog class Declaration
///////////////////////////////////////////////////////////////////////////////
class NetDialog: public wxDialog
{
public:
    NetDialog(wxWindow *parent, wxWindowID id, const wxString &title,
              const wxPoint& pos = wxDefaultPosition,
              const wxSize& size = wxDefaultSize,
              long style = wxDEFAULT_DIALOG_STYLE);
    wxButton *btn_newinput;
    wxButton *btn_delinput;
    wxButton *btn_setwghts;
    wxButton *btn_train;
    wxButton *btn_run;
    wxButton *btn_setdesrd;
    wxButton *btn_showdiag;
    wxButton *btn_quit;
    wxTextCtrl *txt_bias;
    wxTextCtrl *txt_squashval;
    wxStaticText *stc_bias;
    wxStaticText *stc_squashval;
private:
    void OnNewInput(wxCommandEvent &event);
    void OnDelInput(wxCommandEvent &event);
    void OnSetWghts(wxCommandEvent &event);
    void OnSetDesrd(wxCommandEvent &event);
    void OnTrain(wxCommandEvent &event);
    void OnRun(wxCommandEvent &event);
    void OnShowDiag(wxCommandEvent &event);
    void OnQuit(wxCommandEvent &event);
    DECLARE_EVENT_TABLE()
};

// IDs for the menu command
enum
{
    NguiFrame_About,
    NguiFrame_LoadNetwork,
    NguiFrame_NewNetwork,
    NguiFrame_Quit,
    NguiFrame_SaveNetwork,
    NguiFrame_OpenLog,
    NetDialog_NEWINPUT_BTN,
    NetDialog_DELINPUT_BTN,
    NetDialog_SETWGHTS_BTN,
    NetDialog_SETDESRD_BTN,
    NetDialog_TRAIN_BTN,
    NetDialog_RUN_BTN,
    NetDialog_SHOWDIAG_BTN,
    NetDialog_QUIT_BTN,
    NetDialog_BIAS_TXT,
    NetDialog_SQUASHVAL_TXT
};

DECLARE_APP(NguiApp)

#endif   // _GUI_H
