///////////////////////////////////////////////////////////////////////////////
// Name:        nkern_neuron.h
// Purpose:     header for nkernel neuron code
// Author:      Chad Rempp
// Modified by: Chad Rempp
// Created:     03-01-02
// Copyright:   (c) 2003 Chad Rempp
// Licence:     GNU Public License (hey it's what all my friends are doing)
///////////////////////////////////////////////////////////////////////////////
#ifndef NKERN_NEURON_H
#define NKERN_NEURON_H

#include <vector>
#include <fstream>
#include <math.h>

//using namespace std;

// Structure for user defined variables
struct SimData_typ{
    int NumInputs;
    int NumOutputs;
    int NumHiddenLayers;
    int NeuronsPerLayer;
    int NeuronsPerHLayer;
};

#define RANDOM_CLAMP    (((float)rand()-(float)rand())/RAND_MAX)
#define RANDOM_NUM      ((float)rand()/(RAND_MAX+1))

// Default values for an NN
#define NUM_INPUTS             6
#define NUM_OUTPUTS            2
#define DEFAULT_HIDDEN_LAYERS  1
#define DEFAULT_NEURONS_PER_HL 9

//for tweaking the sigmoid response curve
#define ACTIVATION_RESPONSE				1.0f
#define	BIAS							-1.0f

///////////////////////////////////////////////////////////////////////////////
// Neuron structure Declaration
///////////////////////////////////////////////////////////////////////////////
struct Neuron
{
	int				m_NumInputs;
	vector<float>	m_vecWeight;
	Neuron(int NumInputs);
};

///////////////////////////////////////////////////////////////////////////////
// NeuronLayer Structure Declaration
///////////////////////////////////////////////////////////////////////////////
struct NeuronLayer
{
	vector<Neuron>		m_vecNeurons;
	int					m_NumNeurons;
	int					m_NumInputsPerNeuron;
	NeuronLayer(int NumNeurons, 
				int NumInputsPerNeuron);
};

#endif
